###############################################################################
#                                                                             #
#                                Get-MSolUser                                 #
#                                    V2.90                                    #
#                       (C)2006-2014 KoXo Developpement                       #
#                                                                             #
###############################################################################
function log_message
{
Param($Header,$Message)	
$LogDate=Get-Date
$LogInfo="[$($LogDate)]: [$($Header)]: $($Message)"
$LogInfo | Out-File -FilePath $LogFile -Encoding Default -Append -Force
}
###############################################################################
function log_total_errors_count
{
$S="TotalErrorsCount=$($global:total_errors_count)"
$S | Out-File -FilePath $LogFile -Encoding Default -Append -Force
}
###############################################################################
function log_errors_count
{
Param($UserID)
$S="ErrorsCount[$($UserID)]=$($global:errors_count)"
$S | Out-File -FilePath $LogFile -Encoding Default -Append -Force
}
###############################################################################
function check_version
{
$S=Get-Host
if ($S.Version.Major -lt "2")
   {
   $S="Powershell's version must be greater or equal to 2.0 !"
   log_message "Version" $S
   $global:total_errors_count++
   write-host $S -foregroundcolor "red"
   write-host "Press 'Enter' to continue ..."
   Read-Host
   exit
   }
}
###############################################################################
function welcome
{
write-host "Get Msol User for Office 365 $($Version)" -foregroundcolor "white"
write-host "(C) 2006-2014 KoXo Developpement" -foregroundcolor "white"
}
###############################################################################
## Install MSOnline Cmdlets 
function Install-MSOnlineCmdlets()
{
$Res=$false
$DotNET35Path="HKLM:\SOFTWARE\Microsoft\NET Framework Setup\NDP\v3.5"
$DotNet35Present=((Test-Path $DotNET35Path) -and ((Get-ItemProperty $DotNET35Path).Install -eq "1"))
if ($DotNet35Present)
   {
   # Trying to import module
   if (-not(Get-Module -Name "MSOnline")){Get-Module -ListAvailable | Where-Object {$_.name -eq "MSOnline"} | Import-Module}
   # Module is not present
   if (-not(Get-Module -Name "MSOnline"))
      {
      Write-Host "MSOnline Powershell module is not present !" -Foregroundcolor "Red"
      $wc=New-Object System.Net.WebClient
      # Sign-in Assistant
      $SigninAssistantPath="HKLM:\SOFTWARE\Microsoft\MSOIdentityCRL"
      $SigninAssistantPresent=((Test-Path $SigninAssistantPath) -and ((Get-ItemProperty $SigninAssistantPath).TargetDir -ne $null))
      if (!$SigninAssistantPresent)
         {
         if ((Get-WmiObject Win32_OperatingSystem).OSArchitecture -eq "64 bits")
            #{$Binary="http://go.microsoft.com/fwlink/?linkid=236300"}
            #{$Binary="http://go.microsoft.com/fwlink/?LinkId=221500"}
            {$Binary="http://download.microsoft.com/download/E/1/7/E17BB123-19FA-4B91-83DB-903AD0DB5DB8/msoidcli_64.msi"}
            else
            #{$Binary="http://go.microsoft.com/fwlink/?linkid=236299"}
            #{$Binary="http://go.microsoft.com/fwlink/?LinkId=221498"}
            {$Binary="http://download.microsoft.com/download/E/1/7/E17BB123-19FA-4B91-83DB-903AD0DB5DB8/msoidcli_32.msi"}
         # $MyCulture="0x{0:X}" -f(Get-Culture).LCID
         # $Source=$Binary+"&clcid="+$Myculture
         $Source=$Binary
         $Destination=$env:TEMP+"\_SigninAssistant_.msi"
         Write-Host "Trying to download ""Microsoft Online Sign-in Assistant"""
         Write-Host "Url=$($Source)"
         Write-Host "Please, wait ..." -ForegroundColor "Cyan"
         $wc.DownloadFile($Source,$Destination)
         $Install=Start-Process $Destination -Wait -PassThru
         if ($Install.ExitCode -eq 0)
            {
            $S="Microsoft Online Sign-in Assistant installation was OK"
            Write-Host $S -ForegroundColor "Green"
            Log_Message "OK" $S
            }
            else
            {
            $S="Installation failed for Microsoft Online Sign-in Assistant, code : $($Install.ExitCode)"
            Write-Host $S -ForegroundColor "Red"
            Log_Message "ERROR" $S
            } 
         $FileExists=Test-Path $Destination
         If ($FileExists) {Get-Item $Destination | Remove-Item} 
         }
      # MSOnline module
      $MSOnlinePath="HKLM:\SOFTWARE\Microsoft\MSOnlinePowerShell"
      $MSOnlinePresent=((Test-Path $MSOnlinePath) -and ((Get-ItemProperty $MSOnlinePath).InstallPath -ne $null))
      if (!$MSOnlinePresent)
         {
         if ((Get-WmiObject Win32_OperatingSystem).OSArchitecture -eq "64 bits")
            {
            # 64 bits
            if ((Get-WmiObject Win32_OperatingSystem).Version -lt "6")
               {
               # Windows 2003
               $Source="http://www.koxo.net/fichiers/msonline/AdministrationConfig-fr-x64-patched.msi"
               }
               else
               {
               # Windows 2008 and above
               $Binary="http://go.microsoft.com/fwlink/?linkid=236297"
               $Source=$Binary+"&clcid="+$MyCulture
               }
            }
            else
            {
            # 32 bits
            if ((Get-WmiObject Win32_OperatingSystem).Version -lt "6")
               {
               # Windows 2003
               $Source="http://www.koxo.net/fichiers/msonline/AdministrationConfig-fr-x86-patched.msi"
               }
               else
               {
               # Windows 2008 and above
               $Binary="http://go.microsoft.com/fwlink/?linkid=236298"
               $Source=$Binary+"&clcid="+$MyCulture
               }
            }
         $Destination=$env:TEMP+"\_MSOnline_.msi"
         write-host "Trying to download ""Microsoft Online Powershell Module"""
         Write-Host "Url=$($Source)"
         Write-Host "Please, wait ..." -ForegroundColor "Cyan"
         $wc.DownloadFile($Source,$Destination)
         $Install=Start-Process $Destination -Wait -PassThru
         if ($Install.ExitCode -eq 0)
            {
            $S="Microsoft Online Powershell Module installation was OK"
            Write-Host $S -ForegroundColor "Green"
            Log_Message "OK" $S
            }
            else
            {
            $S="Installation failed for Microsoft Online Powershell Module, code : $($Install.ExitCode)"
            Write-Host $S -ForegroundColor "Red"
            Log_Message "ERROR" $S
            }
         $FileExists=Test-Path $Destination
         if ($FileExists) {Get-Item $Destination | Remove-Item} 
         }
      # Import MSOnline Module
      $Mod=Import-Module "MSOnline" -PassThru
      if ([string]::IsNullOrEmpty($Mod)) 
         {
         $S="MSOnline Powershell module is still not present !"
         Write-Host $S -Foregroundcolor "Red"
         Log_Message "ERROR" $S
         Write-Host "Press any key ..."
         Read-Host
         }
         else
         {
         $S="MSOnline Powershell module is now present and loaded !"
         Write-Host $S -Foregroundcolor "Green"
         Log_Message "OK" $S
         $Res=$true
         }
      }
      else
      {
      Write-Host "MSOnline Powershell module is present" -Foregroundcolor "Green"
      $Res=$true
      }
  }
  else
  {
   $S="Please, install Framework .NET V3.5 first !"
   Write-Host $S -ForegroundColor "Red"
   Log_Message "ERROR" $S
   Write-Host "Press any key ..."
   Read-Host
  }
return $Res
}
###############################################################################
function connect_msol
{
Param([string] $MyName,$MyPassword)
$error.Clear()
# Set credential
if ( ([String]::IsNullorEmpty($MyPassword)) -or ([String]::IsNullorEmpty($MyName))  )
   {
   $Cred=Get-Credential
   }
   else
   {
   $SecuredPassword=ConvertTo-SecureString $MyPassword -AsPlainText -Force
   $Cred=New-Object System.Management.Automation.PSCredential $MyName, $SecuredPassword
   }
Connect-MsolService -Credential $Cred -ErrorAction SilentlyContinue
if ([String]::IsNullorEmpty($error[0]))
   {
   $S="Connection was successful to Microsoft Online Services"
	 log_message "OK" $S
   } 
   else 
   {
   $global:total_errors_count++
   $S="Connection was unsuccessful to Microsoft Online Services || $($error[0])"
   log_message "ERROR" $S
   # Display error
   write-host $S -foregroundcolor "red"
   write-host "Press 'Enter' to continue ..."
   Read-Host   
   }   
}
###############################################################################
function msoluser
{
$Error.Clear()
$sku=Get-MSoluser -ErrorAction SilentlyContinue
return $sku
}
###############################################################################
function exec
{
$Log.Text=$Log.Text+"------ Get-MSolAccountSku ------"
$Info = msoluser | Out-String
$Log.Text=$Log.Text+$Info
}
###############################################################################
#                                                                             #
#                                    Main                                     #
#                                                                             #
###############################################################################
#
$global:Version="V2.90"
$global:total_errors_count=0
#
# Office 365 params
#
$Office365LoginName="%OFFICE365_ADMIN%"
$Office365LoginPassword="%OFFICE365_PASSWORD%"
#
# Proxy parameters
#
$ProxyEnabled=$#BOOL{%PROXY_ENABLED%}
$ProxyUser="%PROXY_USER%"     
$ProxyPassword="%PROXY_PASSWORD%"
#
$LogFile=$MyInvocation.MyCommand.Definition 
$LogFile=$LogFile -replace(".ps1",".log")
welcome
check_version
if (Install-MSOnlineCmdlets)
	 {
   connect_msol $Office365LoginName $Office365LoginPassword
   if ($global:total_errors_count -eq 0)
       {
       [void][Reflection.Assembly]::LoadWithPartialName("System.Windows.Forms")
       [void][Reflection.Assembly]::LoadWithPartialName("System.Drawing")
       $panel1 = new-object System.Windows.Forms.Panel
       $buttonClose = new-object System.Windows.Forms.Button
       $groupBox1 = new-object System.Windows.Forms.GroupBox
       $Log = new-object System.Windows.Forms.TextBox
       #
       # panel1
       #
       $panel1.Anchor = [System.Windows.Forms.AnchorStyles]"Bottom,Left,Right"
       $panel1.BackColor = [System.Drawing.Color]::FromArgb(30,139,225)
       $panel1.Controls.Add($buttonClose)
       $panel1.Location = new-object System.Drawing.Point(0, 402)
       $panel1.Name = "panel1"
       $panel1.Size = new-object System.Drawing.Size(673, 35)
       $panel1.TabIndex = 0
       #
       # buttonClose
       #
       $buttonClose.Anchor = [System.Windows.Forms.AnchorStyles]"Top,Bottom,Right"
       $buttonClose.Location = new-object System.Drawing.Point(579, 5)
       $buttonClose.Name = "buttonClose"
       $buttonClose.Size = new-object System.Drawing.Size(89, 25)
       $buttonClose.TabIndex = 0
       $buttonClose.Text = "&Close"
       $buttonClose.UseVisualStyleBackColor = $true
       function OnClick_buttonClose($Sender,$e){$MyForm.Close()}
       $buttonClose.Add_Click( { OnClick_buttonClose $buttonClose $EventArgs} )
       #
       # groupBox1
       #
       $groupBox1.Anchor = [System.Windows.Forms.AnchorStyles]"Top,Bottom,Left,Right"
       $groupBox1.BackColor = [System.Drawing.Color]::FromArgb(30,139,225)
       $groupBox1.Controls.Add($Log)
       $groupBox1.Location = new-object System.Drawing.Point(0, 0)
       $groupBox1.Name = "groupBox1"
       $groupBox1.Size = new-object System.Drawing.Size(672, 402)
       $groupBox1.TabIndex = 2
       $groupBox1.TabStop = $false
       $groupBox1.Text = " Account Sku "
       #
       # Log
       #
       $Log.AcceptsReturn = $true
       $Log.AcceptsTab = $true
       $Log.Anchor = [System.Windows.Forms.AnchorStyles]"Top,Bottom,Left,Right"
       $Log.BackColor = [System.Drawing.Color]::FromArgb(151,192,234)
       $Log.Cursor =[System.Windows.Forms.Cursors]::Default
       $Log.Font = new-object System.Drawing.Font("Courier New",10,[System.Drawing.FontStyle]::Bold)
       $Log.Location = new-object System.Drawing.Point(6, 16)
       $Log.Multiline = $true
       $Log.Name = "Log"
       $Log.ScrollBars =[System.Windows.Forms.ScrollBars]::Both
       $Log.Size = new-object System.Drawing.Size(660, 382)
       $Log.TabIndex = 0
       $Log.WordWrap = $false
       #
       $MyForm = new-object System.Windows.Forms.form
       #
       $MyForm.AutoSize = $true
       $MyForm.ClientSize = new-object System.Drawing.Size(672, 440)
       $MyForm.Controls.Add($groupBox1)
       $MyForm.Controls.Add($panel1)
       $MyForm.Name = "MyForm"
       $MyForm.StartPosition =[System.Windows.Forms.FormStartPosition]::CenterScreen
       $MyForm.Text = "(C)2006-2014 KoXo Developpement | Office 365 Powershell Log"
       #
       exec 
       #
       $MyForm.Topmost = $False
       $MyForm.Add_Shown({$MyForm.Activate()})
       [void] $MyForm.ShowDialog()
       $MyForm.Dispose()
       # close
       }
   }
   else
   {
   $S="MSOnline Powershell module cannot be loaded !"
   Write-Host $S -Foregroundcolor "Red"
   Log_Message "ERROR" $S
   }
log_total_errors_count
